Module: Mack::ViewHelpers::HtmlHelpers
- Defined in:
- lib/mack-javascript/view_helpers/html_helpers.rb
Instance Method Summary collapse
-
#button_to_remote(value = "Submit", options = {}, *original_args) ⇒ Object
Returns a button that links to a remote function.
- #js ⇒ Object
- #link_to_function(link_text, *args, &block) ⇒ Object
- #link_to_remote(link_text, ajax_options, options = {}) ⇒ Object
-
#remote_function(options) ⇒ Object
Returns javascript that does an Ajax call.
-
#update_page {|gs| ... } ⇒ Object
Renders javascript in an html file.
Instance Method Details
#button_to_remote(value = "Submit", options = {}, *original_args) ⇒ Object
Returns a button that links to a remote function.
Example: button_to_remote('Create', :url => '/foo') # =>